==> android-sdk-2.4.0.7-sources.jar: io/adbrix/sdk/domain/IAMConstants.java <==
package io.adbrix.sdk.domain;

public final class IAMConstants {

    public static final String RESPONSE_DATA = "data";
    public static final String RESPONSE_CHECKSUM = "checksum";
    public static final String RESPONSE_STATUS = "status";
    public static final String RESPONSE_MINUTES_TO_EXPIRY = "minutes_to_expiry";
    public static final String RESPONSE_IAM = "in_app_messages";
    public static final String RESPONSE_IAM_CAMPAIGN_ID = "campaign_id";
    public static final String RESPONSE_IAM_PAGE_ORIENTATION = "page_orientation";
    public static final String RESPONSE_IAM_TYPE = "type";
    public static final String RESPONSE_IAM_LAYOUT = "layout";
    public static final String RESPONSE_IAM_CONTENTS = "contents";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE = "image";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_CLICK_ACTION = "click_action";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_CLICK_ACTION_ACTION_ID = "action_id";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_CLICK_ACTION_ACTION_TYPE = "action_type";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_CLICK_ACTION_ACTION_ARG = "action_arg";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_URL = "url";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_URL_PORTRAIT = "portrait";
    public static final String RESPONSE_IAM_CONTENTS_IMAGE_URL_LANDSCAPE = "landscape";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE = "bg_style";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE_OVERLAY_COLOR = "overlay_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT = "text";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_TITLE = "title";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_BODY = "body";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_TITLE_COLOR = "title_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_BODY_COLOR = "body_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_ALIGN = "align";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS = "buttons";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BUTTON_ID = "button_id";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_TEXT = "text";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION = "click_action";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ID = "action_id";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ACTION_TYPE = "action_type";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ACTION_ARG = "action_arg";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_TEXT_COLOR = "text_color";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BORDER_COLOR = "border_color";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON = "default_close_button";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON_COLOR = "color";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION = "sticky_banner_option";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_ALIGN = "align";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION = "click_action";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_ID = "action_id";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_TYPE = "action_type";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_ARG = "action_arg";
    public static final String RESPONSE_IAM_CONTENTS_SCROLLABLE_IMAGE_OPTION = "scrollable_image_option";
    public static final String RESPONSE_IAM_CONTENTS_SCROLLABLE_IMAGE_OPTION_ALIGN = "align";
    public static final String RESPONSE_IAM_TRIGGERS = "triggers";
    public static final String RESPONSE_IAM_TRIGGERS_TYPE = "type";
    public static final String RESPONSE_IAM_TRIGGERS_EVT = "evt";
    public static final String RESPONSE_IAM_TRIGGERS_PRIORITY = "priority";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES = "evt_properties";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_VALUE_TYPE = "value_type";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_PROPERTY = "property";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_CONDITION = "condition";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_VALUES = "values";
    public static final String RESPONSE_IAM_EXT_ATTR = "ext_attr";
    public static final String RESPONSE_IAM_FREQUENCY_CAP = "frequency_cap";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_SESSION = "per_session";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_USER = "per_user";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD = "per_period";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD_PERIOD_IN_MINUTES = "period_in_minutes";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD_PER_PERIOD = "per_period";
    public static final String RESPONSE_IAM_TIMEZONE_OFFSET = "timezone_offset";
    public static final String RESPONSE_IAM_TIMEZONE_TYPE = "timezone_type";
    public static final String RESPONSE_IAM_AVAILABLE_TIME = "available_time";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_DAYS = "days";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_START_MIN = "start_min";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_END_MIN = "end_min";
    public static final String RESPONSE_IAM_START_DATETIME = "start_datetime";
    public static final String RESPONSE_IAM_END_DATETIME = "end_datetime";
    public static final String RESPONSE_IAM_LAST_UPDATED_DATETIME = "last_updated_datetime";
    public static final String RESPONSE_IAM_EXT_CONFIG = "ext_config";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO = "growth_scenario";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CAMPAIGN_ID = "abx_gf_campaign_id";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CYCLE_TIME = "abx_gf_cycle_time";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_STEP_ID = "abx_gf_step_id";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CAMPAIGN_REVISION_NO = "abx_gf_campaign_revision_no";
    public static final String PORTRAIT = "portrait";
    public static final String LANDSCAPE = "landscape";
    public static final String AVAILABLE_TIME_ALL = "all";
    public static final String NO_IMAGE = "no_image";
    public static final String TIMEZONE_GLOBAL = "Global";
    public static final String TIMEZONE_LOCAL = "Local";
    public static final String CHECKSUM_UNCHANGED = "unchanged";
    public static final String CHECKSUM_NO_ACTIVE_CAMPAIGN = "__no_active_campaign__";
    public static final String EVENT_ABX_PREFIX = "abx:";
    public static final String EVENT_CUSTOM_PREFIX = "custom:";

    private IAMConstants() {

    }
}

==> android-sdk-2.5.0.7-sources.jar: io/adbrix/sdk/domain/IAMConstants.java <==
package io.adbrix.sdk.domain;

public final class IAMConstants {

    public static final String RESPONSE_DATA = "data";
    public static final String RESPONSE_CHECKSUM = "checksum";
    public static final String RESPONSE_STATUS = "status";
    public static final String RESPONSE_MINUTES_TO_EXPIRY = "minutes_to_expiry";
    public static final String RESPONSE_COMMON_JS_URL = "common_js_url";
    public static final String RESPONSE_IAM = "in_app_messages";

    public static final String RESPONSE_IAM_IDENFITIER_TYPE = "identifier_type";
    public static final String RESPONSE_IAM_CAMPAIGN_ID = "campaign_id";
    public static final String RESPONSE_IAM_POSITION = "position";
    public static final String RESPONSE_IAM_POSITION_MOBILE = "mobile";
    public static final String RESPONSE_IAM_TYPE = "type";
    public static final String RESPONSE_IAM_CONTENTS = "contents";
    public static final String RESPONSE_IAM_HTML = "html";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE = "bg_style";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_BG_STYLE_OVERLAY_COLOR = "overlay_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT = "text";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_TITLE = "title";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_BODY = "body";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_TITLE_COLOR = "title_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_BODY_COLOR = "body_color";
    public static final String RESPONSE_IAM_CONTENTS_TEXT_ALIGN = "align";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS = "buttons";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BUTTON_ID = "button_id";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_TEXT = "text";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION = "click_action";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ID = "action_id";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ACTION_TYPE = "action_type";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_CLICK_ACTION_ACTION_ARG = "action_arg";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_TEXT_COLOR = "text_color";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_BUTTONS_BORDER_COLOR = "border_color";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON = "default_close_button";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON_COLOR = "color";
    public static final String RESPONSE_IAM_CONTENTS_DEFAULT_CLOSE_BUTTON_BG_COLOR = "bg_color";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION = "sticky_banner_option";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_ALIGN = "align";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION = "click_action";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_ID = "action_id";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_TYPE = "action_type";
    public static final String RESPONSE_IAM_CONTENTS_STICKY_BANNER_OPTION_CLICK_ACTION_ACTION_ARG = "action_arg";
    public static final String RESPONSE_IAM_CONTENTS_SCROLLABLE_IMAGE_OPTION = "scrollable_image_option";
    public static final String RESPONSE_IAM_CONTENTS_SCROLLABLE_IMAGE_OPTION_ALIGN = "align";
    public static final String RESPONSE_IAM_TRIGGERS = "triggers";
    public static final String RESPONSE_IAM_TRIGGERS_TYPE = "type";
    public static final String RESPONSE_IAM_TRIGGERS_EVT = "evt";
    public static final String RESPONSE_IAM_TRIGGERS_PRIORITY = "priority";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES = "evt_properties";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_VALUE_TYPE = "value_type";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_PROPERTY = "property";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_CONDITION = "condition";
    public static final String RESPONSE_IAM_TRIGGERS_EVT_PROPERTIES_VALUES = "values";
    public static final String RESPONSE_IAM_EXT_ATTR = "ext_attr";
    public static final String RESPONSE_IAM_FREQUENCY_CAP = "frequency_cap";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_SESSION = "per_session";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_USER = "per_user";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD = "per_period";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD_PERIOD_IN_MINUTES = "period_in_minutes";
    public static final String RESPONSE_IAM_FREQUENCY_CAP_PER_PERIOD_PER_PERIOD = "per_period";
    public static final String RESPONSE_IAM_TIMEZONE_OFFSET = "timezone_offset";
    public static final String RESPONSE_IAM_TIMEZONE_TYPE = "timezone_type";
    public static final String RESPONSE_IAM_AVAILABLE_TIME = "available_time";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_DAYS = "days";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_START_MIN = "start_min";
    public static final String RESPONSE_IAM_AVAILABLE_TIME_END_MIN = "end_min";
    public static final String RESPONSE_IAM_START_DATETIME = "start_datetime";
    public static final String RESPONSE_IAM_END_DATETIME = "end_datetime";
    public static final String RESPONSE_IAM_LAST_UPDATED_DATETIME = "last_updated_datetime";
    public static final String RESPONSE_IAM_EXT_CONFIG = "ext_config";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO = "growth_scenario";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CAMPAIGN_ID = "abx_gf_campaign_id";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CYCLE_TIME = "abx_gf_cycle_time";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_STEP_ID = "abx_gf_step_id";
    public static final String RESPONSE_IAM_EXT_CONFIG_GROWTH_SCENARIO_CAMPAIGN_REVISION_NO = "abx_gf_campaign_revision_no";
    public static final String AVAILABLE_TIME_ALL = "all";
    public static final String NO_IMAGE = "no_image";
    public static final String TIMEZONE_GLOBAL = "Global";
    public static final String TIMEZONE_LOCAL = "Local";
    public static final String CHECKSUM_UNCHANGED = "unchanged";
    public static final String CHECKSUM_NO_ACTIVE_CAMPAIGN = "__no_active_campaign__";
    public static final String EVENT_ABX_PREFIX = "abx:";
    public static final String EVENT_CUSTOM_PREFIX = "custom:";

    public static final String RESPONSE_IAM_IDENTIFIER_ALL_TYPE = "all";
    public static final String RESPONSE_IAM_IDENTIFIER_USER_ID_TYPE = "user_id";
    public static final String RESPONSE_IAM_IDENTIFIER_DEVICE_ID_TYPE = "device_id";

    private IAMConstants() {

    }
}
